pub trait AutoEscape {
type Escaped: Display;
type Error: Into<Error>;
// Required method
fn askama_auto_escape(&self) -> Result<Self::Escaped, Self::Error>;
}Expand description
Used internally by askama to select the appropriate escaper
Required Associated Types
Sourcetype Error: Into<Error>
type Error: Into<Error>
Early error testing for the input value, usually Infallible
Required Methods
Sourcefn askama_auto_escape(&self) -> Result<Self::Escaped, Self::Error>
fn askama_auto_escape(&self) -> Result<Self::Escaped, Self::Error>
Used internally by askama to select the appropriate escaper
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
Sourceimpl<'a, T: Display + ?Sized, E: Escaper> AutoEscape for &&AutoEscaper<'a, T, E>
Use the provided escaper
impl<'a, T: Display + ?Sized, E: Escaper> AutoEscape for &&AutoEscaper<'a, T, E>
Use the provided escaper