Trait askama::filters::FastWritable

source ·
pub trait FastWritable {
    // Required method
    fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>;
}
Used internally by askama to speed up writing some types.

Types implementing this trait can be written without needing to employ an fmt::Formatter.

Required Methods

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

Used internally by askama to speed up writing some types.

Object Safety

This trait is not object safe.

Implementations on Foreign Types

source

impl FastWritable for bool

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for char

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for i8

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for i16

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for i32

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for i64

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for i128

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for isize

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for str

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for u8

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for u16

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for u32

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for u64

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for u128

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for usize

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for String

Available on crate feature alloc only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for Arguments<'_>

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroI8

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroI16

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroI32

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroI64

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroI128

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroIsize

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroU8

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroU16

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroU32

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroU64

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroU128

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl FastWritable for NonZeroUsize

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T> FastWritable for Pin<T>
where T: Deref, <T as Deref>::Target: FastWritable,

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ToOwned> FastWritable for Cow<'_, T>

Available on crate feature alloc only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for &T

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for &mut T

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for Box<T>

Available on crate feature alloc only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for Rc<T>

Available on crate feature alloc only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for Arc<T>

Available on crate feature alloc only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for Ref<'_, T>

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for RefMut<'_, T>

source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for MutexGuard<'_, T>

Available on crate feature std only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for RwLockReadGuard<'_, T>

Available on crate feature std only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

source

impl<T: FastWritable + ?Sized> FastWritable for RwLockWriteGuard<'_, T>

Available on crate feature std only.
source

fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>

Implementors