Trait askama::filters::FastWritable
source · pub trait FastWritable {
// Required method
fn write_into<W: Write + ?Sized>(&self, dest: &mut W) -> Result<()>;
}Expand description
Used internally by askama to speed up writing some types.
Types implementing this trait can be written without needing to employ an fmt::Formatter.
Required Methods
Object Safety
This trait is not object safe.
Implementations on Foreign Types
sourceimpl FastWritable for bool
impl FastWritable for bool
sourceimpl FastWritable for char
impl FastWritable for char
sourceimpl FastWritable for i8
impl FastWritable for i8
sourceimpl FastWritable for i16
impl FastWritable for i16
sourceimpl FastWritable for i32
impl FastWritable for i32
sourceimpl FastWritable for i64
impl FastWritable for i64
sourceimpl FastWritable for i128
impl FastWritable for i128
sourceimpl FastWritable for isize
impl FastWritable for isize
sourceimpl FastWritable for str
impl FastWritable for str
sourceimpl FastWritable for u8
impl FastWritable for u8
sourceimpl FastWritable for u16
impl FastWritable for u16
sourceimpl FastWritable for u32
impl FastWritable for u32
sourceimpl FastWritable for u64
impl FastWritable for u64
sourceimpl FastWritable for u128
impl FastWritable for u128
sourceimpl FastWritable for usize
impl FastWritable for usize
sourceimpl FastWritable for String
Available on crate feature alloc only.
impl FastWritable for String
Available on crate feature
alloc only.sourceimpl FastWritable for Arguments<'_>
impl FastWritable for Arguments<'_>
sourceimpl FastWritable for NonZeroI8
impl FastWritable for NonZeroI8
sourceimpl FastWritable for NonZeroI16
impl FastWritable for NonZeroI16
sourceimpl FastWritable for NonZeroI32
impl FastWritable for NonZeroI32
sourceimpl FastWritable for NonZeroI64
impl FastWritable for NonZeroI64
sourceimpl FastWritable for NonZeroI128
impl FastWritable for NonZeroI128
sourceimpl FastWritable for NonZeroIsize
impl FastWritable for NonZeroIsize
sourceimpl FastWritable for NonZeroU8
impl FastWritable for NonZeroU8
sourceimpl FastWritable for NonZeroU16
impl FastWritable for NonZeroU16
sourceimpl FastWritable for NonZeroU32
impl FastWritable for NonZeroU32
sourceimpl FastWritable for NonZeroU64
impl FastWritable for NonZeroU64
sourceimpl FastWritable for NonZeroU128
impl FastWritable for NonZeroU128
sourceimpl FastWritable for NonZeroUsize
impl FastWritable for NonZeroUsize
sourceimpl<T> FastWritable for Pin<T>
impl<T> FastWritable for Pin<T>
sourceimpl<T: FastWritable + ToOwned> FastWritable for Cow<'_, T>
Available on crate feature alloc only.
impl<T: FastWritable + ToOwned> FastWritable for Cow<'_, T>
Available on crate feature
alloc only.sourceimpl<T: FastWritable + ?Sized> FastWritable for &T
impl<T: FastWritable + ?Sized> FastWritable for &T
sourceimpl<T: FastWritable + ?Sized> FastWritable for &mut T
impl<T: FastWritable + ?Sized> FastWritable for &mut T
sourceimpl<T: FastWritable + ?Sized> FastWritable for Box<T>
Available on crate feature alloc only.
impl<T: FastWritable + ?Sized> FastWritable for Box<T>
Available on crate feature
alloc only.sourceimpl<T: FastWritable + ?Sized> FastWritable for Rc<T>
Available on crate feature alloc only.
impl<T: FastWritable + ?Sized> FastWritable for Rc<T>
Available on crate feature
alloc only.sourceimpl<T: FastWritable + ?Sized> FastWritable for Arc<T>
Available on crate feature alloc only.
impl<T: FastWritable + ?Sized> FastWritable for Arc<T>
Available on crate feature
alloc only.sourceimpl<T: FastWritable + ?Sized> FastWritable for Ref<'_, T>
impl<T: FastWritable + ?Sized> FastWritable for Ref<'_, T>
sourceimpl<T: FastWritable + ?Sized> FastWritable for RefMut<'_, T>
impl<T: FastWritable + ?Sized> FastWritable for RefMut<'_, T>
sourceimpl<T: FastWritable + ?Sized> FastWritable for MutexGuard<'_, T>
Available on crate feature std only.
impl<T: FastWritable + ?Sized> FastWritable for MutexGuard<'_, T>
Available on crate feature
std only.sourceimpl<T: FastWritable + ?Sized> FastWritable for RwLockReadGuard<'_, T>
Available on crate feature std only.
impl<T: FastWritable + ?Sized> FastWritable for RwLockReadGuard<'_, T>
Available on crate feature
std only.sourceimpl<T: FastWritable + ?Sized> FastWritable for RwLockWriteGuard<'_, T>
Available on crate feature std only.
impl<T: FastWritable + ?Sized> FastWritable for RwLockWriteGuard<'_, T>
Available on crate feature
std only.